@@ -79,6 +79,10 @@ def upload_files(session, s3_bucket: str, source: str, destination: str):
     ) as pbar:
         for fp, op in zip(file_paths, object_paths):
             pbar.write(f"{fp}->{op}")
+            ## hash metadata
+            contents_hash = djsciops_utils.uuid_from_file(fp)
+            # djsciops_utils.log(f"contents_hash: {contents_hash.hex}")
+            ## upload
             session.s3.Bucket(s3_bucket).upload_file(
                 Filename=str(fp),
                 Key=str(op),
@@ -89,4 +93,5 @@ def upload_files(session, s3_bucket: str, source: str, destination: str):
                     use_threads=True,
                 ),
                 Callback=lambda bytes_transferred: pbar.update(bytes_transferred),
+                ExtraArgs={"Metadata": {"contents_hash": contents_hash.hex}},
             )
